@@ -41,12 +41,20 @@ logger.addHandler(console)
 
 # Download library if it does not exist
 import os.path
+from ctypes import cdll
 
-from . import libtools
+from .smelib import libtools
 
-if not os.path.exists(libtools.get_full_libfile()):
+libfile = libtools.get_full_libfile()
+if not os.path.exists(libfile):
     libtools.download_libsme()
 
+try:
+    cdll.LoadLibrary(libfile)
+    from .smelib import _smelib
+except:
+    libtools.compile_interface()
+
 # Provide submodules to the outside
 __all__ = [
     "util",
@@ -57,12 +65,11 @@ __all__ = [
     "cwrapper",
     "echelle",
     "iliffe_vector",
-    "integrate_flux",
     "linelist",
     "nlte",
     "sme_synth",
     "sme",
     "solve",
     "uncertainties",
-    "vald",
+    "smelib",
 ]
